#
# Compute estimator of Pareto parameter alpha after
#
# C. Dalitz: "Estimating Wealth Distribution: Top Tail and Inequality."
# Technischer Bericht Nr. 2016-01, Hochschule Niederrhein,
# Fachbereich Elektrotechnik und Informatik, 2016 
#
# Christoph Dalitz, version 1.0, 2016-02-11
#
# License: GNU GPL version 2
#

source("functions.r")

x <- read.csv("data.csv")
x <- aggregate(list(weight = x$weight), by=list(wealth=x$wealth), FUN=sum)
x <- x[order(x$wealth, decreasing=FALSE),]


# wmin values
xmins <- sort(unique(x$wealth[0.5*10**6 <= x$wealth & x$wealth <= 1.0*10**6]))
n <- length(xmins)


# Optimum for ML
result <- data.frame()
for (xm in xmins) {
  result <- rbind(result, ml.pareto(x, xm))
}
rKS <- ml.pareto(x, xmins[which.min(result$KS)])
rCM <- ml.pareto(x, xmins[which.min(result$CM)])
cat(sprintf("ML-Fit:\n    alpha=%f, wmin=%.0f, KS=%f\n", rKS$alpha, xmins[which.min(result$KS)], rKS$KS))
cat(sprintf("    alpha=%f, wmin=%.0f, CM=%f\n", rCM$alpha, xmins[which.min(result$CM)], rCM$CM))

# Optimum for LSQ without intercept
result <- data.frame()
for (xm in xmins) {
  result <- rbind(result, lsq.pareto(x, xm))
}
rKS <- lsq.pareto(x, xmins[which.min(result$KS)])
rCM <- lsq.pareto(x, xmins[which.min(result$CM)])
cat(sprintf("LSQ-Fit (no intercept):\n    alpha=%f, wmin=%.0f, KS=%f\n", rKS$alpha, xmins[which.min(result$KS)], rKS$KS))
cat(sprintf("    alpha=%f, wmin=%.0f, CM=%f\n", rCM$alpha, xmins[which.min(result$CM)], rCM$CM))

# Optimum for LSQ with intercept
result <- data.frame()
for (xm in xmins) {
  result <- rbind(result, lsq.pareto(x, xm, TRUE))
}
rKS <- lsq.pareto(x, xmins[which.min(result$KS)], TRUE)
rCM <- lsq.pareto(x, xmins[which.min(result$CM)], TRUE)
cat(sprintf("LSQ-Fit (with intercept):\n    alpha=%f, wmin=%.0f, KS=%f\n", rKS$alpha, xmins[which.min(result$KS)], rKS$KS))
cat(sprintf("    alpha=%f, wmin=%.0f, CM=%f\n", rCM$alpha, xmins[which.min(result$CM)], rCM$CM))

# Optimum for Wijk
result <- data.frame()
for (xm in xmins) {
  result <- rbind(result, wijk.pareto(x, xm))
}
rKS <- wijk.pareto(x, xmins[which.min(result$KS)])
rCM <- wijk.pareto(x, xmins[which.min(result$CM)])
cat(sprintf("Wijk-Fit:\n    alpha=%f, wmin=%.0f, KS=%f\n", rKS$alpha, xmins[which.min(result$KS)], rKS$KS))
cat(sprintf("    alpha=%f, wmin=%.0f, CM=%f\n", rCM$alpha, xmins[which.min(result$CM)], rCM$CM))

