#
# Compute one percent share for w_0 from continuity condition after
#
# C. Dalitz: "Estimating Wealth Distribution: Top Tail and Inequality."
# Technischer Bericht Nr. 2016-01, Hochschule Niederrhein,
# Fachbereich Elektrotechnik und Informatik, 2016 
#
# Christoph Dalitz, version 1.0, 2016-02-11
#
# License: GNU GPL version 2
#

do.plots <- FALSE # set to TRUE for plots for debugging

source("functions.r")

wmin <- 561400
alpha <- 1.4723
wmax <- NA
p <- 0.01
w1 <- 500*10**6

s.eck <- c()
s.bach <- c()
s.dalitz <- c()

x <- read.csv("data.csv")
x <- aggregate(list(weight = x$weight), by=list(wealth=x$wealth), FUN=sum)
x <- x[order(x$wealth, decreasing=FALSE),]
N <- sum(x$weight)

mm <- read.csv("richlist.csv")
mm$wealth <- mm$wealth*10**6
mm <- aggregate(list(weight = mm$weight), by=list(wealth=mm$wealth), FUN=sum)
mm <- mm[order(mm$wealth, decreasing=FALSE),]
Nw1 <- sum(mm[mm$wealth >= w1,]$weight)


# range for w0 to try
w0s <-  x[x$wealth >= wmin & x$wealth < 4*10**6, "wealth"]
i <- 2:length(w0s)
w0s <- (w0s[i] + w0s[i-1]) / 2.0
plotmin <- min(w0s)
plotmax <- max(w0s)

# compute density bandwidth
method <- 0
if (method == 1) {
  bws <- seq(0.5, 8, by=0.01)*10**5
  for (bw in bws) {
    d <- density(x$wealth, weights=x$weight/N, from=plotmin, to=plotmax, bw=bw)
    if (!is.unsorted(rev(d$y))) {
      break
    }
  }
} else {
  x.range <- x[x$wealth >= wmin,]
  d <- density(x.range$wealth, weights=x.range$weight/sum(x.range$weight), from=plotmin, to=plotmax, bw="SJ")
  bw <- d$bw
}
#cat(sprintf("bw=%f\n", bw))


# compute f_kernel and f_fit for different values of w0
delta.bach <- c()
delta.eck <- c()
delta.dalitz <- c()
for (w0 in w0s) {
  bach <- C.bach(x, alpha, wmin, w0, wmax)
  eck <- C.eck(x, alpha, wmin, w0, wmax)
  dalitz <- C.dalitz(x, alpha, w1, w0, wmax, mm)
  d <- density(x$wealth, weights=x$weight/N, from=plotmin, to=plotmax, bw=bw)
  fdensity <- approxfun(d$x, d$y)
  delta.bach <- c(delta.bach, (fdensity(w0) - bach$C*w0**(-alpha-1)))
  delta.eck <- c(delta.eck, (fdensity(w0) - eck$C*w0**(-alpha-1)))
  d <- suppressWarnings(density(x$wealth, weights=dalitz$x$weight, from=plotmin, to=plotmax, bw=bw))
  fdensity <- approxfun(d$x, d$y)
  delta.dalitz <- c(delta.dalitz, (fdensity(w0) - dalitz$C*w0**(-alpha-1)))
}

if (do.plots) {
  plot(w0s, delta.dalitz, type='l', col="red")
  lines(c(w0s[1], w0s[length(w0s)]),c(0,0))
  dev.new()
}

w0.eck <- w0s[min(which(delta.eck <= 0))]
w0.bach <- w0s[min(which(delta.bach <= 0))]
w0.dalitz <- w0s[min(which(delta.dalitz >= 0))]
#cat(sprintf("Zero at %f\n", w0))
bach <- C.bach(x, alpha, wmin, w0.bach, wmax)
eck <- C.eck(x, alpha, wmin, w0.eck, wmax)
dalitz <- C.dalitz(x, alpha, w1, w0.dalitz, wmax, mm)

# plot resulting density
plotmin <- max(c(wmin, w0.dalitz-0.8*10**6))
plotmax <- w0.dalitz+0.3*10**6
if (do.plots) {
  par(lwd=2, ps=20, mar=c(3,3,2,2)+0.1, family="Times")
}
# histogram
i <- 2:(nrow(x)-1)
wi <- (x$wealth[i] + x$wealth[i-1]) / 2.0
hi = 2*x$weight[i] / ((x$wealth[i+1] - x$wealth[i-1])*N)
if (do.plots) {
  plot(wi[wi >= plotmin & wi <= plotmax], hi[wi >= plotmin & wi <= plotmax], main=NA, ylab=NA, xlab=NA, xlim=c(plotmin,plotmax), type='s', col="grey")
}
# kernel density
d <- suppressWarnings(density(x$wealth, weights=dalitz$x$weight, from=plotmin, to=w0.dalitz, bw=bw))
if (do.plots) {
  lines(d, col="blue", lty=2)
  xx <- seq(w0.dalitz, plotmax, by=20000)
  lines(xx, dalitz$C*(xx**(-alpha-1)), col=c("red2"))
  legend("topright", c("histogram", "kernel density", "Pareto"), lty=c(1,2,1), col=c("grey","blue","red2"), y.intersp=1.5)
}

s.eck <- compute.share(p=p, x=eck$x, w0=w0.eck, alpha=alpha, C=eck$C, wmax=wmax)
cat(sprintf("w0=%f, s.eck=%f\n", w0.eck, s.eck))
s.bach <- compute.share(p=p, x=bach$x, w0=w0.bach, alpha=alpha, C=bach$C, wmax=wmax)
cat(sprintf("w0=%f, s.bach=%f\n", w0.bach, s.bach))
s.dalitz <- compute.share(p=p, x=dalitz$x, w0=w0.dalitz, alpha=alpha, C=dalitz$C, wmax=wmax)
cat(sprintf("w0=%f, s.dalitz=%f\n", w0.dalitz, s.dalitz))
