#
# Compute one percent share for fixed values of w_0 after
#
# C. Dalitz: "Estimating Wealth Distribution: Top Tail and Inequality."
# Technischer Bericht Nr. 2016-01, Hochschule Niederrhein,
# Fachbereich Elektrotechnik und Informatik, 2016 
#
# Christoph Dalitz, version 1.0, 2016-02-11
#
# License: GNU GPL version 2
#

source("functions.r")

wmin <- 561400
alpha <- 1.4735
wmax <- NA
p <- 0.01
w1 <- 500*10**6

x <- read.csv("data.csv")
x <- aggregate(list(weight = x$weight), by=list(wealth=x$wealth), FUN=sum)
x <- x[order(x$wealth, decreasing=FALSE),]

mm <- read.csv("richlist.csv")
mm$wealth <- mm$wealth*10**6
mm <- aggregate(list(weight = mm$weight), by=list(wealth=mm$wealth), FUN=sum)
mm <- mm[order(mm$wealth, decreasing=FALSE),]
Nw1 <- sum(mm[mm$wealth >= w1,]$weight)


for (w0 in c(wmin/10**6, 1, 3, 5, 7, 9, 11)*10**6) {

  # compute different normalization constants C
  bach <- C.bach(x, alpha, wmin, w0, wmax)
  s.bach <- compute.share(p=p, x=bach$x, w0=w0, alpha=alpha, C=bach$C, wmax=wmax)
  eck <- C.eck(x, alpha, wmin, w0, wmax)
  s.eck <- compute.share(p=p, x=eck$x, w0=w0, alpha=alpha, C=eck$C, wmax=wmax)

  dalitz <- C.dalitz(x, alpha, w1, w0, wmax, mm)
  s.dalitz <- compute.share(p=p, x=dalitz$x, w0=w0, alpha=alpha, C=dalitz$C, wmax=wmax)
  
  #cat(sprintf("w0=%i, C.bach=%f, C.eck=%f, C.dalitz=%f\n", w0, bach$C, eck$C, dalitz$C))
  cat(sprintf("w0=%i, s.bach=%f, s.eck=%f, s.dalitz=%f\n", w0, s.bach, s.eck, s.dalitz))

}
