#
# Plot histogram/kernel density and Pareto tail fit after
#
# C. Dalitz: "Estimating Wealth Distribution: Top Tail and Inequality."
# Technischer Bericht Nr. 2016-01, Hochschule Niederrhein,
# Fachbereich Elektrotechnik und Informatik, 2016 
#
# Christoph Dalitz, version 1.0, 2016-02-11
#
# License: GNU GPL version 2
#

w0 <- 3*10**6
plotmin <- w0-1.2*10**6
plotmax <- w0+1.2*10**6
alpha <- 1.48

x <- read.csv("data.csv")
x <- aggregate(list(weight = x$weight), by=list(wealth=x$wealth), FUN=sum)
x <- x[order(x$wealth, decreasing=FALSE),]
x$wealth <- x$wealth

# plot density and Pareto fit
par(lwd=2, ps=20, mar=c(3,3,2,2)+0.1, family="Times")
d <- suppressWarnings(density(x$wealth, weights=x$weight, from=plotmin, to=w0, bw=2.5*10**5))

# histogram
i <- 2:(nrow(x)-1)
wi <- (x$wealth[i] + x$wealth[i-1]) / 2.0
hi = 2*x$weight[i] / (x$wealth[i+1] - x$wealth[i-1])
plot(wi[wi > plotmin & wi < plotmax & wi <= w0], hi[wi > plotmin & wi < plotmax & wi<= w0], main=NA, ylab=NA, xlab=NA, xlim=c(plotmin,plotmax), type='s')

# kernel density
lines(d, col="blue", lty=2)

tailweight <- sum(x[x$wealth >= w0,]$weight)
C <- alpha * tailweight * w0**alpha
xx <- seq(w0, plotmax, by=20000)
lines(xx, C*(xx**(-alpha-1)), col=c("red2"))
legend("topright", c("histogram", "kernel density", "Pareto"), lty=c(1,2,1), col=c("black","blue","red2"), y.intersp=1.5)

lines(c(w0,w0), c(-1,1.5*10**(-8)), lty=3, col=rgb(100,100,100,maxColorValue=255))
text(w0, 1.5*10**(-8), expression(italic('w')[0]), pos=4, col=rgb(100,100,100,maxColorValue=255))
